@@ -5,6 +5,7 @@ class File(GAsset):
     def __init__(self, name, localPath, title=None, description=None, var=None, messageType="file"):
         super().__init__(name=name, title=title, description=description, var=var, messageType=messageType)
         self.localPath = localPath
+        self.path = None
 
     def set_path(self, path):
         self.localPath = path
@@ -28,7 +29,7 @@ class File(GAsset):
 
         result = super().to_json()
         result['localPath'] = self.localPath 
-        result['path'] = None
+        result['path'] = self.path
         result['extension'] = self.extension
         result['filename'] = self.filename
 
