@@ -35,5 +35,5 @@ class GAsset():
         return None
     
     def send(self):
-        self.storage.save(path=self.get_path(), metadata=self.to_json())
+        self.path = self.storage.save(path=self.get_path(), metadata=self.to_json())
         self.notifier.something_has_changed(self.to_json())
