@@ -14,6 +14,6 @@ class Notifier:
 
     def something_has_changed(self, metadata):
         if self.isActive:
-            message = {"message": "Generic output updated", "metatada": metadata.get()}
+            message = {"message": "Generic output updated", "metatada": metadata}
             self.producer.send(self.topic, json.dumps(message).encode('utf-8'))
 
